@@ -1,2 +1,7 @@
 """Discovergy API."""
+
 from pydiscovergy.discovergy import Discovergy
+
+__all__ = [
+    "Discovergy",
+]
